=========
nullspace
=========

.. image:: https://img.shields.io/pypi/v/nullspace.svg
        :target: https://pypi.python.org/pypi/nullspace


Python package for doing science.

* `Documentation <https://ke-zhang-rd.github.io/nullspace>`_
* Free software: 3-clause BSD license


Features
--------

* TODO
